IsSystem

Trait IsSystem 

pub trait IsSystem {
    // Required method
    fn is_system(&self) -> bool;
}
Determine if a teyrchain is a system teyrchain or not.

Required Methods

fn is_system(&self) -> bool

Returns true if a teyrchain is a system teyrchain, false otherwise.

Implementors